package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.UseGuide;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.WelfareGuideMapper;
import com.ruoyi.system.domain.WelfareGuide;
import com.ruoyi.system.service.IWelfareGuideService;

/**
 * 小程序党建福利信息Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-07-14
 */
@Service
public class WelfareGuideServiceImpl implements IWelfareGuideService 
{
    @Autowired
    private WelfareGuideMapper welfareGuideMapper;

    /**
     * 查询小程序党建福利信息
     * 
     * @param id 小程序党建福利信息主键
     * @return 小程序党建福利信息
     */
    @Override
    public WelfareGuide selectWelfareGuideById(Long id)
    {
        return welfareGuideMapper.selectWelfareGuideById(id);
    }

    /**
     * 查询小程序党建福利信息列表
     * 
     * @param welfareGuide 小程序党建福利信息
     * @return 小程序党建福利信息
     */
    @Override
    public List<WelfareGuide> selectWelfareGuideList(WelfareGuide welfareGuide)
    {
        return welfareGuideMapper.selectWelfareGuideList(welfareGuide);
    }

    /**
     * 新增小程序党建福利信息
     * 
     * @param welfareGuide 小程序党建福利信息
     * @return 结果
     */
    @Override
    public int insertWelfareGuide(WelfareGuide welfareGuide)
    {
        welfareGuide.setCreateTime(DateUtils.getNowDate());
        return welfareGuideMapper.insertWelfareGuide(welfareGuide);
    }

    /**
     * 修改小程序党建福利信息
     * 
     * @param welfareGuide 小程序党建福利信息
     * @return 结果
     */
    @Override
    public int updateWelfareGuide(WelfareGuide welfareGuide)
    {
        welfareGuide.setUpdateTime(DateUtils.getNowDate());
        return welfareGuideMapper.updateWelfareGuide(welfareGuide);
    }

    /**
     * 批量删除小程序党建福利信息
     * 
     * @param ids 需要删除的小程序党建福利信息主键
     * @return 结果
     */
    @Override
    public int deleteWelfareGuideByIds(Long[] ids)
    {
        return welfareGuideMapper.deleteWelfareGuideByIds(ids);
    }

    /**
     * 删除小程序党建福利信息信息
     * 
     * @param id 小程序党建福利信息主键
     * @return 结果
     */
    @Override
    public int deleteWelfareGuideById(Long id)
    {
        return welfareGuideMapper.deleteWelfareGuideById(id);
    }

    @Override
    public AjaxResult getInfoNew() {
        WelfareGuide welfareGuide = welfareGuideMapper.getInfoNew();
        if(welfareGuide == null){
            welfareGuide = new WelfareGuide();
        }
        return AjaxResult.success("访问成功",welfareGuide);
    }
}
